==> gatsby-core-theme-30.1.1.tgz: package/src/components/organisms/accordion/variants/template-two/index.js <==
import React from 'react';
import PropTypes from 'prop-types';

import styles from './template-two.module.scss';
import keygen from '~helpers/keygen';
import Image from '~hooks/gatsby-img';
import Link from '~hooks/link';
import LazyImage from '~hooks/lazy-image';
import { imagePrettyUrl } from '~helpers/getters';

const TemplateTwo = ({ module, author }) => {
  const { items } = module;
  const usernames = [
    'mindbrew94',
    'nebulaecho49',
    'opalight79',
    'peachsunrise60',
    'quartzbeat23',
    'ripplequiet58',
    'solarpulse99',
    'tidalwave402',
    'vineglow47',
    'wavemender23',
    'zenithsky11',
    'abysslooker56',
    'lilyMoonbeam',
    'nathanVoyage',
    'rachelSunset',
    'leoWildfire',
    'miaRipple',
    'ethanSky',
    'oliviaMist',
    'samOcean',
    'avaWhisper',
    'adam',
    'jonathan',
    'sophia',
    'max',
    'ellie',
    'jake',
    'lily',
    'nathan',
    'rachel',
    'leo',
    'mia',
    'ethan',
    'olivia',
    'sam',
    'ava',
    'tyler',
    'isabella',
    'aiden',
    'grace',
    'noah',
    'emma',
    'lucas',
    'qroxon',
    'plentix',
    'flubro',
    'drinzo',
    'yerkum',
    'slinx',
    'frevoq',
    'gwintol',
    'crunom',
    'blivart',
    'jepro',
    'kuzlim',
    'zoplonk',
    'twindax',
  ];

  return (
    <>
      <div className={styles.accordionContainer || ''}>
        {items.map(
          (item) =>
            item.content && (
              <div key={keygen()} className={styles.accordionItem || ''}>
                <div className={styles.question}>
                  <span>{item.title}</span>
                  <div className={styles.commenter}>
                    <span>{usernames[Math.floor(Math.random() * usernames.length)]}</span>
                    <Image
                      className={styles.userAvatar}
                      alt="user-avatar"
                      filename="user_avatar"
                      width={36}
                      height={36}
                    />
                  </div>
                </div>
                <div className={`${styles.answer || ''} ${styles.active}`}>
                  <div dangerouslySetInnerHTML={{ __html: item.content }} />
                  {author && (
                    <div className={styles.author}>
                      <span>{author.name}</span>
                      <Link to={author.profile_page_path} className={styles.authorImage}>
                        <LazyImage
                          alt={author.name}
                          loading="eager"
                          width={36}
                          height={36}
                          src={imagePrettyUrl(author.image, 36, 36)}
                        />
                      </Link>
                    </div>
                  )}
                </div>
              </div>
            )
        )}
      </div>
    </>
  );
};

TemplateTwo.propTypes = {
  module: PropTypes.shape({
    anchor_label: PropTypes.string,
    items: PropTypes.arrayOf(
      PropTypes.shape({
        title: PropTypes.string,
        content: PropTypes.string,
      })
    ),
  }).isRequired,
  styles: PropTypes.shape({}),
  author: PropTypes.shape({
    image: PropTypes.string,
    profile_page_path: PropTypes.string,
    name: PropTypes.string,
  }),
};

export default TemplateTwo;

==> gatsby-core-theme-31.0.0.tgz: package/src/components/organisms/accordion/variants/template-two/index.js <==
import React from 'react';
import PropTypes from 'prop-types';

import styles from './template-two.module.scss';
import keygen from '~helpers/keygen';
import Image from '~hooks/gatsby-img';
import Link from '~hooks/link';
import LazyImage from '~hooks/lazy-image';
import { imagePrettyUrl } from '~helpers/getters';

const TemplateTwo = ({ module, author }) => {
  const { items } = module;
  const usernames = [
    'mindbrew94',
    'nebulaecho49',
    'opalight79',
    'peachsunrise60',
    'quartzbeat23',
    'ripplequiet58',
    'solarpulse99',
    'tidalwave402',
    'vineglow47',
    'wavemender23',
    'zenithsky11',
    'abysslooker56',
    'lilyMoonbeam',
    'nathanVoyage',
    'rachelSunset',
    'leoWildfire',
    'miaRipple',
    'ethanSky',
    'oliviaMist',
    'samOcean',
    'avaWhisper',
    'adam',
    'jonathan',
    'sophia',
    'max',
    'ellie',
    'jake',
    'lily',
    'nathan',
    'rachel',
    'leo',
    'mia',
    'ethan',
    'olivia',
    'sam',
    'ava',
    'tyler',
    'isabella',
    'aiden',
    'grace',
    'noah',
    'emma',
    'lucas',
    'qroxon',
    'plentix',
    'flubro',
    'drinzo',
    'yerkum',
    'slinx',
    'frevoq',
    'gwintol',
    'crunom',
    'blivart',
    'jepro',
    'kuzlim',
    'zoplonk',
    'twindax',
  ];

  return (
    <>
      <div className={styles.accordionContainer || ''}>
        {items.map(
          (item, key) =>
            item.content && (
              <div key={keygen()} className={styles.accordionItem || ''}>
                <div className={styles.question}>
                  <span>{item.title}</span>
                  <div className={styles.commenter}>
                    <span>{usernames[key]}</span>
                    <Image
                      className={styles.userAvatar}
                      alt="user-avatar"
                      filename="user_avatar"
                      width={36}
                      height={36}
                    />
                  </div>
                </div>
                <div className={`${styles.answer || ''} ${styles.active}`}>
                  <div dangerouslySetInnerHTML={{ __html: item.content }} />
                  {typeof author === 'object' && (
                    <div className={styles.author}>
                      <span>{author.name}</span>
                      <Link to={author.profile_page_path} className={styles.authorImage}>
                        <LazyImage
                          alt={author.name}
                          loading="eager"
                          width={36}
                          height={36}
                          src={imagePrettyUrl(author.image, 36, 36)}
                        />
                      </Link>
                    </div>
                  )}
                </div>
              </div>
            )
        )}
      </div>
    </>
  );
};

TemplateTwo.propTypes = {
  module: PropTypes.shape({
    anchor_label: PropTypes.string,
    items: PropTypes.arrayOf(
      PropTypes.shape({
        title: PropTypes.string,
        content: PropTypes.string,
      })
    ),
  }).isRequired,
  styles: PropTypes.shape({}),
  author: PropTypes.shape({
    image: PropTypes.string,
    profile_page_path: PropTypes.string,
    name: PropTypes.string,
  }),
};

export default TemplateTwo;
